import 'dart:typed_data';

import 'package:firebase_storage/firebase_storage.dart';
import 'package:uuid/uuid.dart';

import '../../abg_utils.dart';

class ImageData{
  String serverPath = "";
  String localFile = "";

  ImageData({this.serverPath = "", this.localFile = ""});

  Map<String, dynamic> toJson() => {
    'serverPath': serverPath,
    'localFile': localFile,
  };

  factory ImageData.fromJson(Map<String, dynamic> data){
    return ImageData(
      serverPath: (data["serverPath"] != null) ? data["serverPath"] : "",
      localFile: (data["localFile"] != null) ? data["localFile"] : "",
    );
  }

  factory ImageData.createEmpty(){
    return ImageData();
  }
}

Future<String?> uploadImage(String _type, Uint8List _imageData) async {
  if (_type != "webSiteAppLogo" && _type != "webSiteAppLogo" && _type != "adminPanelAppLogo")
    return "uploadImage: Unregistered type";

  try{
    var f = Uuid().v4();
    var localFile = "$f.jpg";

    if (_type == "providerAppLogo" || _type == "webSiteAppLogo" || _type == "adminPanelAppLogo")
      localFile = "settings/$f.jpg";

    var firebaseStorageRef = FirebaseStorage.instance.ref().child(localFile);
    TaskSnapshot s = await firebaseStorageRef.putData(_imageData);
    var serverPath = await s.ref.getDownloadURL();

    if (_type == "providerAppLogo"){
      appSettings.providerLogoLocal = localFile;
      appSettings.providerLogoServer = serverPath;
    }
    if (_type == "webSiteAppLogo"){
      appSettings.websiteLogoLocal = localFile;
      appSettings.websiteLogoServer = serverPath;
    }
    if (_type == "adminPanelAppLogo"){
      appSettings.adminPanelLogoLocal = localFile;
      appSettings.adminPanelLogoServer = serverPath;
    }

  }catch(ex){
    return "uploadFile " + ex.toString();
  }
}

Future<String?> deleteImage(String _type) async {
  if (_type != "webSiteAppLogo" && _type != "providerAppLogo" && _type != "adminPanelAppLogo")
    return "uploadImage: Unregistered type";

  try{
    if (_type == "providerAppLogo"){
      var firebaseStorageRef = FirebaseStorage.instance.ref().child(appSettings.providerLogoLocal);
      await firebaseStorageRef.delete();
      appSettings.providerLogoLocal = "";
      appSettings.providerLogoServer = "";
    }
    if (_type == "webSiteAppLogo"){
      var firebaseStorageRef = FirebaseStorage.instance.ref().child(appSettings.websiteLogoLocal);
      await firebaseStorageRef.delete();
      appSettings.websiteLogoLocal = "";
      appSettings.websiteLogoServer = "";
    }
    if (_type == "adminPanelAppLogo"){
      var firebaseStorageRef = FirebaseStorage.instance.ref().child(appSettings.adminPanelLogoLocal);
      await firebaseStorageRef.delete();
      appSettings.adminPanelLogoLocal = "";
      appSettings.adminPanelLogoServer = "";
    }

  }catch(ex){
    return "deleteImage " + ex.toString();
  }
}